# Utils

General utilities complimenting and expanding on standard python.

# Release History
See also [Older Releases](OLDER_RELEASES.md) and [Wish-list](WISHLIST.md)

## 1.0.22

* Added *plotx* (Various helpers for MatPlotLib)

## 1.0.21

* Added dict_set and dict_get to *ds*

# Setup & Install

```
pip install utils-nuuuwan
```
